==> php55-owncloud-8.2.2.tgz: share/owncloud/apps/files/l10n/gl.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Almacenamento non dispoñíbel",
    "Storage invalid" : "Almacenamento incorrecto",
    "Unknown error" : "Produciuse un erro descoñecido",
    "Could not move %s - File with this name already exists" : "Non foi posíbel mover %s; Xa existe un ficheiro con ese nome.",
    "Could not move %s" : "Non foi posíbel mover %s",
    "Permission denied" : "Permiso denegado",
    "The target folder has been moved or deleted." : "O cartafol de destino foi movido ou eliminado.",
    "The name %s is already used in the folder %s. Please choose a different name." : "Xa existe o nome %s no cartafol %s. Escolla outro nome.",
    "Error when creating the file" : "Produciuse un erro ao crear o ficheiro",
    "Error when creating the folder" : "Produciuse un erro ao crear o cartafol",
    "Unable to set upload directory." : "Non é posíbel configurar o directorio de envíos.",
    "Invalid Token" : "Marca incorrecta",
    "No file was uploaded. Unknown error" : "Non se enviou ningún ficheiro. Produciuse un erro descoñecido.",
    "There is no error, the file uploaded with success" : "Non houbo erros, o ficheiro enviouse correctamente",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "O ficheiro enviado excede a directiva indicada por upload_max_filesize de php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "O ficheiro enviado excede da directiva MAX_FILE_SIZE especificada no formulario HTML",
    "The uploaded file was only partially uploaded" : "O ficheiro so foi parcialmente enviado",
    "No file was uploaded" : "Non se enviou ningún ficheiro",
    "Missing a temporary folder" : "Falta o cartafol temporal",
    "Failed to write to disk" : "Produciuse un erro ao escribir no disco",
    "Not enough storage available" : "Non hai espazo de almacenamento abondo",
    "Upload failed. Could not find uploaded file" : "O envío fracasou. Non foi posíbel atopar o ficheiro enviado",
    "Upload failed. Could not get file info." : "O envío fracasou. Non foi posíbel obter información do ficheiro.",
    "Invalid directory." : "O directorio é incorrecto.",
    "Files" : "Ficheiros",
    "All files" : "Todos os ficheiros",
    "Favorites" : "Favoritos",
    "Home" : "Inicio",
    "Close" : "Pechar",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Non é posíbel enviar {filename}, xa que ou é un directorio ou ten 0 bytes",
    "Total file size {size1} exceeds upload limit {size2}" : "O tamaño total do ficheiro {size1} excede do límite de envío {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Non hai espazo libre abondo, o seu envío é de {size1} mais só dispón de {size2}",
    "Upload cancelled." : "Envío cancelado.",
    "Could not get result from server." : "Non foi posíbel obter o resultado do servidor.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "O envío do ficheiro está en proceso. Saír agora da páxina cancelará o envío.",
    "Actions" : "Accións",
    "Download" : "Descargar",
    "Rename" : "Renomear",
    "Delete" : "Eliminar",
    "Details" : "Detalles",
    "Select" : "Seleccionar",
    "Pending" : "Pendentes",
    "Unable to determine date" : "Non é posíbel determinar a data",
    "This operation is forbidden" : "Esta operación está prohibida",
    "This directory is unavailable, please check the logs or contact the administrator" : "Este directorio non está dispoñíbel, comprobe os rexistros ou póñase en contacto co administrador",
    "Error moving file." : "Produciuse un erro ao mover o ficheiro.",
    "Error moving file" : "Produciuse un erro ao mover o ficheiro",
    "Error" : "Erro",
    "{new_name} already exists" : "Xa existe un {new_name}",
    "Could not rename file" : "Non foi posíbel renomear o ficheiro",
    "Could not create file" : "Non foi posíbel crear o ficheiro",
    "Could not create folder" : "Non foi posíbel crear o cartafol",
    "Error deleting file." : "Produciuse un erro ao eliminar o ficheiro.",
    "No entries in this folder match '{filter}'" : "Non hai entradas neste cartafol coincidentes con «{filter}»",
    "Name" : "Nome",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "_%n folder_::_%n folders_" : ["%n cartafol","%n cartafoles"],
    "_%n file_::_%n files_" : ["%n ficheiro","%n ficheiros"],
    "{dirs} and {files}" : "{dirs} e {files}",
    "You don’t have permission to upload or create files here" : "Non ten permisos para enviar ou crear ficheiros aquí.",
    "_Uploading %n file_::_Uploading %n files_" : ["Cargando %n ficheiro","Cargando %n ficheiros"],
    "New" : "Novo",
    "\"{name}\" is an invalid file name." : "«{name}» é un nome incorrecto de ficheiro.",
    "File name cannot be empty." : "O nome de ficheiro non pode estar baleiro",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "O espazo de almacenamento de {owner} está cheo, non é posíbel actualizar ou sincronizar máis os ficheiros!",
    "Your storage is full, files can not be updated or synced anymore!" : "O seu espazo de almacenamento está cheo, non é posíbel actualizar ou sincronizar máis os ficheiros!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "O espazo de almacenamento de {owner} está case cheo ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "O seu espazo de almacenamento está case cheo ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["coincidente con «{filter}»","coincidentes con «{filter}»"],
    "Path" : "Ruta",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Marcado como favorito",
    "Favorite" : "Favorito",
    "Upload" : "Enviar",
    "Text file" : "Ficheiro de texto",
    "Folder" : "Cartafol",
    "New folder" : "Novo cartafol",
    "An error occurred while trying to update the tags" : "Produciuse un erro ao tentar actualizar as etiquetas",
    "A new file or folder has been <strong>created</strong>" : "<strong>Creouse</strong> un novo ficheiro ou cartafol",
    "A file or folder has been <strong>changed</strong>" : "<strong>Cambiouse</strong> un ficheiro ou cartafol",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limita as notificacións sobre a creación e modificación dos seus <strong>ficheiros favoritos</strong> <em>(só os fluxos)</em>",
    "A file or folder has been <strong>deleted</strong>" : "<strong>Eliminouse</strong> un ficheiro ou cartafol",
    "A file or folder has been <strong>restored</strong>" : "Foi <strong>restaurado</strong> satisfactoriamente un ficheiro ou cartafol",
    "You created %1$s" : "Creou %1$s",
    "%2$s created %1$s" : "%2$s creado %1$s",
    "%1$s was created in a public folder" : "%1$s foi creado nun cartafol público",
    "You changed %1$s" : "Cambiou %1$s",
    "%2$s changed %1$s" : "%2$s cambiado %1$s",
    "You deleted %1$s" : "Eliminou %1$s",
    "%2$s deleted %1$s" : "%2$s eliminado %1$s",
    "You restored %1$s" : "Vostede restaurou %1$s",
    "%2$s restored %1$s" : "%2$s restaurou %1$s",
    "%s could not be renamed as it has been deleted" : "Non é posíbel renomear %s xa que foi eliminado",
    "%s could not be renamed" : "%s non pode cambiar de nome",
    "Upload (max. %s)" : "Envío (máx. %s)",
    "File handling" : "Manexo de ficheiro",
    "Maximum upload size" : "Tamaño máximo do envío",
    "max. possible: " : "máx. posíbel: ",
    "Save" : "Gardar",
    "Can not be edited from here due to insufficient permissions." : "Non pode ser editado desde aquí por mor de falta de permisos.",
    "Settings" : "Axustes",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Empregue esta ligazón para  <a href=\"%s\" target=\"_blank\">acceder aos seus ficheiros mediante WebDAV</a>",
    "Cancel upload" : "Cancelar o envío",
    "No files in here" : "Aquí non hai ficheiros",
    "Upload some content or sync with your devices!" : "Envíe algún contido ou sincronice cos seus dispositivos!",
    "No entries found in this folder" : "Non se atoparon entradas neste cartafol",
    "Select all" : "Seleccionar todo",
    "Upload too large" : "Envío grande de máis",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Os ficheiros que tenta enviar exceden do tamaño máximo permitido neste servidor",
    "Files are being scanned, please wait." : "Estanse analizando os ficheiros. Agarde.",
    "Currently scanning" : "Análise actual",
    "No favorites" : "Non hai favoritos",
    "Files and folders you mark as favorite will show up here" : "Os ficheiros e cartafoles que marque como favoritos amosaranse aquí"
},
"nplurals=2; plural=(n != 1);");

==> php55-owncloud-9.0.0.tgz: share/owncloud/apps/files/l10n/gl.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Almacenamento non dispoñíbel",
    "Storage invalid" : "Almacenamento incorrecto",
    "Unknown error" : "Produciuse un erro descoñecido",
    "Unable to set upload directory." : "Non é posíbel configurar o directorio de envíos.",
    "Invalid Token" : "Marca incorrecta",
    "No file was uploaded. Unknown error" : "Non se enviou ningún ficheiro. Produciuse un erro descoñecido.",
    "There is no error, the file uploaded with success" : "Non houbo erros, o ficheiro enviouse correctamente",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "O ficheiro enviado excede a directiva indicada por upload_max_filesize de php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "O ficheiro enviado excede da directiva MAX_FILE_SIZE especificada no formulario HTML",
    "The uploaded file was only partially uploaded" : "O ficheiro so foi parcialmente enviado",
    "No file was uploaded" : "Non se enviou ningún ficheiro",
    "Missing a temporary folder" : "Falta o cartafol temporal",
    "Failed to write to disk" : "Produciuse un erro ao escribir no disco",
    "Not enough storage available" : "Non hai espazo de almacenamento abondo",
    "The target folder has been moved or deleted." : "O cartafol de destino foi movido ou eliminado.",
    "Upload failed. Could not find uploaded file" : "O envío fracasou. Non foi posíbel atopar o ficheiro enviado",
    "Upload failed. Could not get file info." : "O envío fracasou. Non foi posíbel obter información do ficheiro.",
    "Invalid directory." : "O directorio é incorrecto.",
    "Files" : "Ficheiros",
    "All files" : "Todos os ficheiros",
    "Favorites" : "Favoritos",
    "Home" : "Inicio",
    "Close" : "Pechar",
    "Upload cancelled." : "Envío cancelado.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Non é posíbel enviar {filename}, xa que ou é un directorio ou ten 0 bytes",
    "Total file size {size1} exceeds upload limit {size2}" : "O tamaño total do ficheiro {size1} excede do límite de envío {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Non hai espazo libre abondo, o seu envío é de {size1} mais só dispón de {size2}",
    "Could not get result from server." : "Non foi posíbel obter o resultado do servidor.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "O envío do ficheiro está en proceso. Saír agora da páxina cancelará o envío.",
    "Actions" : "Accións",
    "Download" : "Descargar",
    "Rename" : "Renomear",
    "Delete" : "Eliminar",
    "Disconnect storage" : "Desconectar o almacenamento",
    "Unshare" : "Deixar de compartir",
    "Details" : "Detalles",
    "Select" : "Seleccionar",
    "Pending" : "Pendentes",
    "Unable to determine date" : "Non é posíbel determinar a data",
    "This operation is forbidden" : "Esta operación está prohibida",
    "This directory is unavailable, please check the logs or contact the administrator" : "Este directorio non está dispoñíbel, comprobe os rexistros ou póñase en contacto co administrador",
    "No entries in this folder match '{filter}'" : "Non hai entradas neste cartafol coincidentes con «{filter}»",
    "Name" : "Nome",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "_%n folder_::_%n folders_" : ["%n cartafol","%n cartafoles"],
    "_%n file_::_%n files_" : ["%n ficheiro","%n ficheiros"],
    "{dirs} and {files}" : "{dirs} e {files}",
    "You don’t have permission to upload or create files here" : "Non ten permisos para enviar ou crear ficheiros aquí.",
    "_Uploading %n file_::_Uploading %n files_" : ["Cargando %n ficheiro","Cargando %n ficheiros"],
    "New" : "Novo",
    "\"{name}\" is an invalid file name." : "«{name}» é un nome incorrecto de ficheiro.",
    "File name cannot be empty." : "O nome de ficheiro non pode estar baleiro",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "O espazo de almacenamento de {owner} está cheo, non é posíbel actualizar ou sincronizar máis os ficheiros!",
    "Your storage is full, files can not be updated or synced anymore!" : "O seu espazo de almacenamento está cheo, non é posíbel actualizar ou sincronizar máis os ficheiros!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "O espazo de almacenamento de {owner} está case cheo ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "O seu espazo de almacenamento está case cheo ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["coincidente con «{filter}»","coincidentes con «{filter}»"],
    "Path" : "Ruta",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Marcado como favorito",
    "Favorite" : "Favorito",
    "Folder" : "Cartafol",
    "New folder" : "Novo cartafol",
    "Upload" : "Enviar",
    "An error occurred while trying to update the tags" : "Produciuse un erro ao tentar actualizar as etiquetas",
    "A new file or folder has been <strong>created</strong>" : "<strong>Creouse</strong> un novo ficheiro ou cartafol",
    "A file or folder has been <strong>changed</strong>" : "<strong>Cambiouse</strong> un ficheiro ou cartafol",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limita as notificacións sobre a creación e modificación dos seus <strong>ficheiros favoritos</strong> <em>(só os fluxos)</em>",
    "A file or folder has been <strong>deleted</strong>" : "<strong>Eliminouse</strong> un ficheiro ou cartafol",
    "A file or folder has been <strong>restored</strong>" : "Foi <strong>restaurado</strong> satisfactoriamente un ficheiro ou cartafol",
    "You created %1$s" : "Creou %1$s",
    "%2$s created %1$s" : "%2$s creado %1$s",
    "%1$s was created in a public folder" : "%1$s foi creado nun cartafol público",
    "You changed %1$s" : "Cambiou %1$s",
    "%2$s changed %1$s" : "%2$s cambiado %1$s",
    "You deleted %1$s" : "Eliminou %1$s",
    "%2$s deleted %1$s" : "%2$s eliminado %1$s",
    "You restored %1$s" : "Vostede restaurou %1$s",
    "%2$s restored %1$s" : "%2$s restaurou %1$s",
    "Upload (max. %s)" : "Envío (máx. %s)",
    "File handling" : "Manexo de ficheiro",
    "Maximum upload size" : "Tamaño máximo do envío",
    "max. possible: " : "máx. posíbel: ",
    "Save" : "Gardar",
    "Settings" : "Axustes",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Empregue esta ligazón para  <a href=\"%s\" target=\"_blank\">acceder aos seus ficheiros mediante WebDAV</a>",
    "Cancel upload" : "Cancelar o envío",
    "No files in here" : "Aquí non hai ficheiros",
    "Upload some content or sync with your devices!" : "Envíe algún contido ou sincronice cos seus dispositivos!",
    "No entries found in this folder" : "Non se atoparon entradas neste cartafol",
    "Select all" : "Seleccionar todo",
    "Upload too large" : "Envío grande de máis",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Os ficheiros que tenta enviar exceden do tamaño máximo permitido neste servidor",
    "No favorites" : "Non hai favoritos",
    "Files and folders you mark as favorite will show up here" : "Os ficheiros e cartafoles que marque como favoritos amosaranse aquí",
    "Text file" : "Ficheiro de texto"
},
"nplurals=2; plural=(n != 1);");
